aboutsummaryrefslogtreecommitdiffstats
path: root/src/gamma-x-randr.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/gamma-x-randr.h (renamed from src/gamma-vidmode.h)54
1 files changed, 27 insertions, 27 deletions
diff --git a/src/gamma-vidmode.h b/src/gamma-x-randr.h
index 5b38798..cc4ddde 100644
--- a/src/gamma-vidmode.h
+++ b/src/gamma-x-randr.h
@@ -15,12 +15,12 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef LIBGAMMA_GAMMA_VIDMODE_H
#define LIBGAMMA_GAMMA_VIDMODE_H
#ifndef HAVE_GAMMA_METHOD_VIDMODE
# error Including gamma-vidmode.h without HAVE_GAMMA_METHOD_VIDMODE
#endif
@@ -32,7 +32,7 @@
*
* @param this The data structure to fill with the method's capabilities
*/
-void libgamma_vidmode_method_capabilities(libgamma_method_capabilities_t* restrict this);
+void libgamma_x_randr_method_capabilities(libgamma_method_capabilities_t* restrict this);
/**
* Initialise an allocated site state
@@ -47,7 +47,7 @@ void libgamma_vidmode_method_capabilities(libgamma_method_capabilities_t* restri
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_site_initialise(libgamma_site_state_t* restrict this,
+int libgamma_x_randr_site_initialise(libgamma_site_state_t* restrict this,
char* restrict site);
/**
@@ -55,7 +55,7 @@ int libgamma_vidmode_site_initialise(libgamma_site_state_t* restrict this,
*
* @param this The site state
*/
-void libgamma_vidmode_site_destroy(libgamma_site_state_t* restrict this);
+void libgamma_x_randr_site_destroy(libgamma_site_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a site to the system settings
@@ -64,7 +64,7 @@ void libgamma_vidmode_site_destroy(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_site_restore(libgamma_site_state_t* restrict this);
+int libgamma_x_randr_site_restore(libgamma_site_state_t* restrict this);
/**
@@ -76,7 +76,7 @@ int libgamma_vidmode_site_restore(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_partition_initialise(libgamma_partition_state_t* restrict this,
+int libgamma_x_randr_partition_initialise(libgamma_partition_state_t* restrict this,
libgamma_site_state_t* restrict site, size_t partition);
/**
@@ -84,7 +84,7 @@ int libgamma_vidmode_partition_initialise(libgamma_partition_state_t* restrict t
*
* @param this The partition state
*/
-void libgamma_vidmode_partition_destroy(libgamma_partition_state_t* restrict this);
+void libgamma_x_randr_partition_destroy(libgamma_partition_state_t* restrict this);
/**
* Release all resources held by a partition state
@@ -92,7 +92,7 @@ void libgamma_vidmode_partition_destroy(libgamma_partition_state_t* restrict thi
*
* @param this The partition state
*/
-void libgamma_vidmode_partition_free(libgamma_partition_state_t* restrict this);
+void libgamma_x_randr_partition_free(libgamma_partition_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a partition to the system settings
@@ -101,7 +101,7 @@ void libgamma_vidmode_partition_free(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_partition_restore(libgamma_partition_state_t* restrict this);
+int libgamma_x_randr_partition_restore(libgamma_partition_state_t* restrict this);
/**
@@ -113,7 +113,7 @@ int libgamma_vidmode_partition_restore(libgamma_partition_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_initialise(libgamma_crtc_state_t* restrict this,
libgamma_partition_state_t* restrict partition, size_t crtc);
/**
@@ -121,7 +121,7 @@ int libgamma_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
*
* @param this The CRTC state
*/
-void libgamma_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this);
+void libgamma_x_randr_crtc_destroy(libgamma_crtc_state_t* restrict this);
/**
* Release all resources held by a CRTC state
@@ -129,7 +129,7 @@ void libgamma_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this);
*
* @param this The CRTC state
*/
-void libgamma_vidmode_crtc_free(libgamma_crtc_state_t* restrict this);
+void libgamma_x_randr_crtc_free(libgamma_crtc_state_t* restrict this);
/**
* Restore the gamma ramps for a CRTC to the system settings for that CRTC
@@ -138,7 +138,7 @@ void libgamma_vidmode_crtc_free(libgamma_crtc_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this);
+int libgamma_x_randr_crtc_restore(libgamma_crtc_state_t* restrict this);
/**
@@ -149,7 +149,7 @@ int libgamma_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this);
* @param fields OR:ed identifiers for the information about the CRTC that should be read
* @return Zero on success, -1 on error. On error refer to the error reports in `this`.
*/
-int libgamma_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict this,
+int libgamma_x_randr_get_crtc_information(libgamma_crtc_information_t* restrict this,
libgamma_crtc_state_t* restrict crtc, int32_t fields);
/**
@@ -160,7 +160,7 @@ int libgamma_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps_t* restrict ramps);
/**
@@ -171,7 +171,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps_t ramps);
@@ -183,7 +183,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps32_t* restrict ramps);
/**
@@ -194,7 +194,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps32_t ramps);
@@ -206,7 +206,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps64_t* restrict ramps);
/**
@@ -217,7 +217,7 @@ int libgamma_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
libgamma_gamma_ramps64_t ramps);
@@ -229,7 +229,7 @@ int libgamma_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsf_t* restrict ramps);
/**
@@ -240,7 +240,7 @@ int libgamma_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsf_t ramps);
/**
@@ -251,7 +251,7 @@ int libgamma_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsd_t* restrict ramps);
/**
@@ -262,7 +262,7 @@ int libgamma_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_vidmode_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+int libgamma_x_randr_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
libgamma_gamma_rampsd_t ramps);
@@ -15,12 +15,12 @@
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef LIBGAMMA_GAMMA_VIDMODE_H
-#define LIBGAMMA_GAMMA_VIDMODE_H
+#ifndef LIBGAMMA_GAMMA_X_RANDR_H
+#define LIBGAMMA_GAMMA_X_RANDR_H
-#ifndef HAVE_GAMMA_METHOD_VIDMODE
-# error Including gamma-vidmode.h without HAVE_GAMMA_METHOD_VIDMODE
+#ifndef HAVE_GAMMA_METHOD_X_RANDR
+# error Including gamma-x-randr.h without HAVE_GAMMA_METHOD_X_RANDR
#endif